@@ -7,7 +7,6 @@ import numpy as np
 import os
 import torch
 from soco_trainer_plugin.core.database.data_processor_base import ProcessorBase
-from configs.config import EnvVar
 
 
 class TrainerPlugin(ABC):
@@ -32,8 +31,9 @@ class TrainerPlugin(ABC):
         root_dir = os.path.dirname(os.path.realpath(__file__)).replace('soco_trainer_plugin', '')
         return f"{root_dir}/trained_models/{task_id}/{model_id}"
 
-    def setup(self, params, task_id, op_id):
-        root_dir = os.path.dirname(os.path.realpath(__file__)).replace('soco_trainer_plugin', '')
+    def setup(self, params, task_id, op_id, root_dir=None):
+        if not root_dir:
+            root_dir = os.path.dirname(os.path.realpath(__file__)).replace('soco_trainer_plugin', '')
         if "seed" in params:
             self.seed_everything(params["seed"])
         params = Dict2Obj(params)
